Clazz.declarePackage("J.api");
(function(){
var c$ = Clazz.declareInterface(J.api, "JmolGestureServerInterface");
})();
;//5.0.1-v7 Fri Nov 14 10:17:11 CST 2025
